set more off
set matsize 2000
global path="Put your path here"

use "$path\wiot_full.dta" , clear

**dropping unnecessaries: last 8 rows of the excel files at the bottom**
drop if row_country=="CIF" | row_country=="GO" | row_country=="ITM" | row_country=="PUA" | row_country=="PUF" | row_country=="TOT" | row_country=="TXP" | row_country=="VA"


save "$path\1_without extra row_country.dta", replace

*creating a raw data for usage later and at the end*
*intermediate one*
use "$path\1_without extra row_country.dta", clear
drop if col_item>35
tostring row_item, generate(row_item_s)
tostring col_item, generate(col_item_s)
gen input=row_country+row_item_s
gen output=col_country+col_item_s
drop row_item_s col_item_s value 
encode input, generate(inputn)
encode output, generate(outputn)
drop input output
ren inputn input
ren outputn output
save "$path\0-raw_data.dta", replace
*final one*
use "$path\1_without extra row_country.dta", clear
collapse (first) value, by(year row_country row_item)
tostring row_item, generate(row_item_s)
drop value
gen input=row_country+row_item_s
encode input, generate(inputn)
save "$path\0_1-raw_data_1.dta", replace



*dropping inventories, because the total absorption is the summation in each row (input industry) minus the changes in inventories*
use "$path\1_without extra row_country.dta", clear
drop if col_item==42

*calculation of absorption*
by year row_country row_item, sort: egen Absorption=sum(value)


save "$path\2_with absorption.dta", replace
*dropping unnecessary columns >35*
drop if col_item>35


sort year row_country col_country row_item col_item
save "$path\3_only 35 industries.dta", replace


*creating delta*
use "$path\3_only 35 industries.dta", clear
gen delta = value / Absorption
replace delta = 0 if delta == .
save "$path\4_with delta.dta", replace

merge 1:1 year row_country col_country row_item col_item using "$path\0-raw_data.dta", nogenerate
keep year input output delta
order year input output delta

save "$path\5_input-output names.dta", replace



*Upstreamnes*
use "$path\5_input-output names.dta", clear

gen invcoeff = delta

replace invcoeff = -invcoeff
replace invcoeff = 1+invcoeff if input == output
keep year input output invcoeff



forval i=1995(1)2011 {
	preserve
		keep if year==`i'
		keep input output invcoeff
		sort input output
		reshape wide invcoeff, i(input) j(output) 
		mkmat invcoeff*, matrix(IObis`i') 
		drop invcoeff*
		matrix InvIObis = inv(IObis`i')
		svmat InvIObis, names(matcol)
		reshape long InvIObisr, i(input) j(output)
		rename InvIObisr invindex
		collapse (sum) invindex, by(input)
		rename invindex upstreamness
		sort input
		order input upstreamness
		gen year=`i'
		save "$path\U_data`i'.dta", replace
	restore
	}
	
	use "$path\U_data1995.dta", clear
	forval n=1996(1)2011 {
		append using "$path\U_data`n'.dta"
		erase "$path\U_data`n'.dta"
		}
erase "$path\U_data1995.dta"
compress
save "$path\U_Complete", replace

rename input inputn
decode inputn, generate(input)
merge 1:1 year input using "$path\0_1-raw_data_1.dta", nogenerate
drop row_item_s
sort year row_country row_item
save "$path\U_Complete", replace


*ranking in each year*
gsort +yea -upstreamness
by year, sort: gen rank=_n
drop input inputn
order year row_country row_item upstreamness rank
save "$path\ranked_Upstreamness", replace



*erasing rest of the files*
erase "$path\0_1-raw_data_1.dta"
erase "$path\0-raw_data.dta"
erase "$path\1_without extra row_country.dta"
erase "$path\2_with absorption.dta"
erase "$path\3_only 35 industries.dta"
erase "$path\4_with delta.dta"
erase "$path\5_input-output names.dta"
